# Isso – a commenting server similar to Disqus

Isso – *Ich schrei sonst* – is a lightweight commenting server written in
Python and JavaScript. It aims to be a drop-in replacement for
[Disqus](http://disqus.com).

See **[posativ.org/isso](http://posativ.org/isso/)** for more details and
documentation.

![Isso in Action](http://posativ.org/~tmp/isso-sample.png)

## License
MIT, see [LICENSE](LICENSE).

## Development
Refer to the docs for
[Installing from Source](https://posativ.org/isso/docs/install/#install-from-source).
